@@ -292,65 +292,6 @@ class RequestHandler(tornado.web.RequestHandler):
     #
     #
     #
-    #     self.debug = None
-    #     self.css_debug = None
-    #     self.js_debug = None
-    #
-    #
-    #     self.cdn = None
-    #     self.browser_type = None
-    #     self.db = None
-    #     self.acct_db = None
-    #     self.auth_callback = None
-    #
-    #     self.message_queue = None
-    #     self.queue_config = None
-    #
-    #     self.cache_db = None
-    #     self.cache_config = None
-    #
-    #     self.files_db = None
-    #     self.dbs = None
-    #
-    #     self.db_refer = None
-    #
-    #     self.session = None
-    #     self.statsd = None
-    #
-    #     self.locale_callback = None
-    #
-    #     self.hacking_ie = None
-    #
-    #     # maybe not a good design
-    #     # self.template_urls = None
-    #     # self.template_keys = None
-    #
-    #     self.api_messages = None
-    #
-    #     self.project_version = None
-    #     self.project_name = None
-    #     self.project_desc = None
-    #     self.project_keywords = None
-    #
-    #     self.css_version = None
-    #     self.js_version = None
-    #
-    #
-    #     self.favicon = None
-    #     self.copyright_text = None
-    #     self.copyright = None
-    #     self.author = None
-    #
-    #
-    #     #mail client
-    #     _smtp_config = None
-    #
-    #     if _smtp_config:
-    #         self.smtp = None
-    #     else:
-    #         self.smtp = None
-    #
-    #     # ez-hack-end
     #
     #
     #     # UIModules are available as both `modules` and `_tt_modules` in the
@@ -368,65 +309,66 @@ class RequestHandler(tornado.web.RequestHandler):
 
 
     def initialize(self):
-
-        self.debug = self.application.settings.get('debug', False)
-        self.css_debug = self.application.settings.get('css_debug', False)
-        self.js_debug = self.application.settings.get('js_debug', False)
+        self.debug = None
+        self.css_debug = None
+        self.js_debug = None
 
 
-        self.cdn = self.application.settings.get('cdn', '')
-        self.browser_type = self.application.settings.get('browser_default_type', 'mobile')
-        self.db = self.application.settings.get('db', NotImplemented)
-        self.acct_db = self.application.settings.get('acct_db', NotImplemented)
-        self.auth_callback = self.application.settings.get('auth_callback', NotImplemented)
+        self.cdn = None
+        self.browser_type = None
+        self.db = None
+        self.acct_db = None
+        self.auth_callback = None
 
-        self.message_queue = self.application.settings.get('message_queue', NotImplemented)
-        self.queue_config = self.application.settings.get('queue_config', NotImplemented)
+        self.message_queue = None
+        self.queue_config = None
 
-        self.cache_db = self.application.settings.get('cache_db', NotImplemented)
-        self.cache_config = self.application.settings.get('cache_config', NotImplemented)
+        self.cache_db = None
+        self.cache_config = None
 
-        self.files_db = self.application.settings.get('files_db', NotImplemented)
-        self.dbs = self.application.settings.get('dbs', NotImplemented)
+        self.files_db = None
+        self.dbs = None
 
-        self.db_refer = self.application.settings.get('db_refer', NotImplemented)
+        self.db_refer = None
 
-        self.session = self.application.settings.get('session', NotImplemented)
-        self.statsd = self.application.settings.get('statsd', NotImplemented)
+        self.session = None
+        self.statsd = None
 
-        self.locale_callback = self.application.settings.get('locale_callback', NotImplemented)
+        self.locale_callback = None
 
         self.hacking_ie = None
 
         # maybe not a good design
-        # self.template_urls = self.application.settings.get('template_urls', NotImplemented)
-        # self.template_keys = self.application.settings.get('template_keys', NotImplemented)
+        # self.template_urls = None
+        # self.template_keys = None
 
-        self.api_messages = self.application.settings.get('api_messages', {})
+        self.api_messages = None
 
-        self.project_version = self.application.settings.get('version', None)
-        self.project_name = self.application.settings.get('project', {}).get('name','')
-        self.project_desc = self.application.settings.get('project', {}).get('desc','')
-        self.project_keywords = self.application.settings.get('project', {}).get('keywords','')
+        self.project_version = None
+        self.project_name = None
+        self.project_desc = None
+        self.project_keywords = None
 
-        self.css_version = self.application.settings.get('css_version', str(int(time())))
-        self.js_version = self.application.settings.get('js_version', str(int(time())))
+        self.css_version = None
+        self.js_version = None
 
 
-        self.favicon = self.application.settings.get('favicon', "/static/favicon.ico")
-        self.copyright_text = self.application.settings.get('copyright_text', '')
-        self.copyright = self.application.settings.get('copyright', '')
-        self.author = self.application.settings.get('author', '')
+        self.favicon = None
+        self.copyright_text = None
+        self.copyright = None
+        self.author = None
 
 
         #mail client
-        _smtp_config = self.application.settings.get('smtp')
+        _smtp_config = None
 
         if _smtp_config:
-            self.smtp = MailClient2(_smtp_config)
+            self.smtp = None
         else:
             self.smtp = None
 
+        # ez-hack-end
+
         pass
 
 
